@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -69,7 +69,8 @@ ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
         checkModules();
         KMessageBox::information(this, i18n("Close KMail before importing data. Some plugins will modify KMail config file."));
     }
-    auto helpMenu = new KHelpMenu(this, KAboutData::applicationData(), true);
+    auto helpMenu = new KHelpMenu(this, KAboutData::applicationData());
+    helpMenu->setShowWhatsThis(true);
     // Initialize menu
     QMenu *menu = helpMenu->menu();
     helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("kmail")));
